import 'dart:convert';
import 'dart:io';

String camelCase(String text) {
  String capitalize(Match m) => m[0].substring(0, 1).toUpperCase() + m[0].substring(1);
  String skip(String s) => '';
  return text.splitMapJoin(RegExp(r'[a-zA-Z0-9]+'), onMatch: capitalize, onNonMatch: skip);
}

String camelCaseFirstLower(String text) {
  final camelCaseText = camelCase(text);
  final firstChar = camelCaseText.substring(0, 1).toLowerCase();
  final rest = camelCaseText.substring(1);
  return '$firstChar$rest';
}

void main(List<String> arguments) {
  var file = File(arguments.first);

  if (!file.existsSync()) {
    print('Cannot find the file "${arguments.first}".');
  }

  var content = file.readAsStringSync();
  Map<String, dynamic> iconfont = json.decode(content);
  List<dynamic> icons = iconfont['glyphs'];
  Map<String, String> iconDefinitions = {};

  icons.forEach((icon) {
    var iconName = icon['font_class'];
    iconDefinitions[iconName] = generateExampleIcon(iconName);
  });

  List<String> generatedOutput = [
    '',
    "import 'package:don_icons/don_icons.dart';",
    "import 'package:don_icons_example/example_icon.dart';",
    '',
    '// THIS FILE IS AUTOMATICALLY GENERATED!',
    '',
    'final icons = <ExampleIcon>[',
  ];

  generatedOutput.addAll(iconDefinitions.values);

  generatedOutput.add('];');

  File output = File('example/lib/icons.dart');
  output.writeAsStringSync(generatedOutput.join('\n'));
}

String generateExampleIcon(String iconName) {

  iconName = camelCaseFirstLower(iconName);

  return "ExampleIcon(DonIcons.$iconName, '$iconName'),";
}
