import 'dart:convert';
import 'dart:io';

String camelCase(String text) {
  String capitalize(Match m) => m[0].substring(0, 1).toUpperCase() + m[0].substring(1);
  String skip(String s) => '';
  return text.splitMapJoin(RegExp(r'[a-zA-Z0-9]+'), onMatch: capitalize, onNonMatch: skip);
}

String camelCaseFirstLower(String text) {
  final camelCaseText = camelCase(text);
  final firstChar = camelCaseText.substring(0, 1).toLowerCase();
  final rest = camelCaseText.substring(1);
  return '$firstChar$rest';
}

void main(List<String> arguments) {
  var file = File(arguments.first);
  if (!file.existsSync()) {
    print('Cannot find the file "${arguments.first}".');
  }

  var content = file.readAsStringSync();
  Map<String, dynamic> iconfont = json.decode(content);
  List<dynamic> icons = iconfont['glyphs'];
  Map<String, String> iconDefinitions = {};

  icons.forEach((icon) {
    var iconName = icon['font_class'];
    var unicode = icon['unicode'];
    iconDefinitions[iconName] = generateIconDefinition(iconName, unicode);
  });

  List<String> generatedOutput = [
    'library don_icons;',
    '',
    "import 'package:flutter/widgets.dart';",
    '',
    '''
    class IconDataDon extends IconData {
      const IconDataDon(int codePoint) : super(codePoint, fontFamily: 'Iconfont', fontPackage: 'don_icons');
    }
    ''',
  ];

  generatedOutput.addAll([
    '',
    '// THIS FILE IS AUTOMATICALLY GENERATED!',
    '',
    'class DonIcons {',
  ]);

  generatedOutput.addAll(iconDefinitions.values);

  generatedOutput.add('}');

  File output = File('lib/don_icons.dart');
  output.writeAsStringSync(generatedOutput.join('\n'));
}

String generateIconDefinition(String iconName, String unicode) {
  iconName = camelCaseFirstLower(iconName);
  return 'static const IconData $iconName = const IconDataDon(0x$unicode);';
}
